*****************************
LSQ Image Intensity Matching
*****************************

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. currentmodule:: jwst.wiimatch.match

.. automodule:: jwst.wiimatch.match
   :members:
   :undoc-members:
